import request from '@/config/axios'

// 教育经历 VO
export interface EduExpVO {
  id: number // id
  userId: number // 用户id
  schoolId: number // 学校id
  schoolName: string // 学校名称（没有选择系统企业可自定义）
  educationType: number // 学历（0初中及以下 | 1中专/中技 | 2高中 | 3大专 | 4 本科 5 硕士 6 博士 99 其他）
  educationSystemType: number // 学制类型（0 全日制 | 1 非全日制）
  majorId: number // 专业id
  major: string // 专业名称（没有选择系统企业可自定义）
  startTime: Date // 在校开始日期
  endTime: Date // 在校结束时间
  content: string // 在校经历
}

// 教育经历 API
export const EduExpApi = {
  // 查询教育经历分页
  getEduExpPage: async (params: any) => {
    return await request.get({ url: `/menduner/system/edu-exp/page`, params })
  },

  // 查询教育经历详情
  getEduExp: async (id: number) => {
    return await request.get({ url: `/menduner/system/edu-exp/get?id=` + id })
  },

  // 新增教育经历
  createEduExp: async (data: EduExpVO) => {
    return await request.post({ url: `/menduner/system/edu-exp/create`, data })
  },

  // 修改教育经历
  updateEduExp: async (data: EduExpVO) => {
    return await request.put({ url: `/menduner/system/edu-exp/update`, data })
  },

  // 删除教育经历
  deleteEduExp: async (id: number) => {
    return await request.delete({ url: `/menduner/system/edu-exp/delete?id=` + id })
  },

  // 导出教育经历 Excel
  exportEduExp: async (params) => {
    return await request.download({ url: `/menduner/system/edu-exp/export-excel`, params })
  }
}