import request from '@/config/axios'

// 猎寻服务 VO
export interface HuntVO {
  id: number // id
  name: string // 姓名
  enterpriseName: string // 企业名称
  phone: string // 联系方式
  status: string // 状态（0待处理|1已联系）
  remark: string // 备注
}

// 猎寻服务 API
export const HuntApi = {
  // 查询猎寻服务分页
  getHuntPage: async (params: any) => {
    return await request.get({ url: `/menduner/system/hunt/page`, params })
  },

  // 查询猎寻服务详情
  getHunt: async (id: number) => {
    return await request.get({ url: `/menduner/system/hunt/get?id=` + id })
  },

  // 新增猎寻服务
  createHunt: async (data: HuntVO) => {
    return await request.post({ url: `/menduner/system/hunt/create`, data })
  },

  // 修改猎寻服务
  updateHunt: async (data: HuntVO) => {
    return await request.put({ url: `/menduner/system/hunt/update`, data })
  },

  // 处理猎寻服务
  dealHunt: async (data: HuntVO) => {
    return await request.put({ url: '/menduner/system/hunt/processed', data })
  },

  // 删除猎寻服务
  deleteHunt: async (id: number) => {
    return await request.delete({ url: `/menduner/system/hunt/delete?id=` + id })
  },

  // 导出猎寻服务 Excel
  exportHunt: async (params) => {
    return await request.download({ url: `/menduner/system/hunt/export-excel`, params })
  }
}