import request from '@/config/axios'

// 门墩儿-用户登录 VO
export interface MdeUserVO {
  id: number // 用户ID
  username: string // 用户账号
  password: string // 密码
  email: string // 用户邮箱
  phone: string // 手机号码
  avatar: string // 头像地址
  status: number // 帐号状态（0正常 1停用）
  registerIp: string // 注册 IP
  registerTerminal: string // 注册终端
  loginIp: string // 最后登录IP
  loginDate: Date // 最后登录时间
}

// 门墩儿-用户登录 API
export const MdeUserApi = {
  // 查询门墩儿-用户登录分页
  getMdeUserPage: async (params: any) => {
    return await request.get({ url: `/menduner/system/mde-user/page`, params })
  },

  // 查询门墩儿-用户登录详情
  getMdeUser: async (id: number) => {
    return await request.get({ url: `/menduner/system/mde-user/get?id=` + id })
  },

  // 新增门墩儿-用户登录
  createMdeUser: async (data: MdeUserVO) => {
    return await request.post({ url: `/menduner/system/mde-user/create`, data })
  },

  // 修改门墩儿-用户登录
  updateMdeUser: async (data: MdeUserVO) => {
    return await request.put({ url: `/menduner/system/mde-user/update`, data })
  },

  // 删除门墩儿-用户登录
  deleteMdeUser: async (id: number) => {
    return await request.delete({ url: `/menduner/system/mde-user/delete?id=` + id })
  },

  // 导出门墩儿-用户登录 Excel
  exportMdeUser: async (params) => {
    return await request.download({ url: `/menduner/system/mde-user/export-excel`, params })
  },

  // 禁用账户
  disabledUserAccount: async (id: number) => {
    return await request.post({ url: `/menduner/system/mde-user/disable?id=${id}` })
  },

  // 启用账户
  enableUserAccount: async (id: number) => {
    return await request.post({ url: `/menduner/system/mde-user/enable?id=${id}` })
  },
}